@@ -21,43 +21,42 @@
  */
 
 #include "nettypes.h"
-#include "stringf.h"
+#include <iomanip>
+#include <sstream>
 
 using namespace std;
-using namespace stringf;
-
 
 /* Format an IPv4 address in a static char buffer */
 string fmt(const IPAddress& addr) throw ()
 {
-	string buf;
+	stringstream buf;
 	for (int i = 0; i < 4; i++)
 	{
 		if (i > 0)
-			buf += '.';
-		buf += fmt((int)(((const unsigned char*)(const in_addr*)addr)[i]));
+			buf << '.';
+		buf << (int)(((const unsigned char*)(const in_addr*)addr)[i]);
 	}
-	return buf;
+	return buf.str();
 }
 
 /* Format a MAC address in a static char buffer */
 string fmt(const struct ether_addr& addr) throw ()
 {
-	string buf;
+	stringstream buf;
 	for (int i = 0; i < 6; i++)
 	{
 		if (i > 0)
-			buf += ':';
-		buf += fmt("%02x", (int)(((const unsigned char*)&addr)[i]));
+			buf << ':';
+		buf << hex << setfill('0') << setw(2) << (int)(((const unsigned char*)&addr)[i]);
 	}
-	return buf;
+	return buf.str();
 }
 
-IPAddress::IPAddress(const std::string& str) throw (ConsistencyCheckException)
+IPAddress::IPAddress(const std::string& str) throw (wibble::exception::Consistency)
 {
 	if (inet_aton(str.c_str(), &addr) == 0)
 		// Not valid
-		throw ConsistencyCheckException("parsing IP address \"" + str + "\"");
+		throw wibble::exception::Consistency("parsing IP address \"" + str + "\"", "not a valid IP address");
 }
 
 bool IPAddress::operator==(const IPAddress& ip) const
