@@ -144,8 +144,6 @@ static void memdump(const string& prefix, unsigned char* mem, int size) throw ()
 
 void* NetWatcher::main()
 {
-	struct pcap_pkthdr pcap_header;
-
 	// Let the signals be caught by some other process
 	sigset_t sigs, oldsigs;
 	sigfillset(&sigs);
@@ -162,9 +160,18 @@ void* NetWatcher::main()
 	try {
 		while (true)
 		{
-			unsigned char* packet = (u_char *)pcap_next (pcap_interface, &pcap_header);
-			if (packet == 0)
-				throw wibble::exception::Pcap (pcap_geterr(pcap_interface), "getting a new packet from the network");
+			struct pcap_pkthdr* pcap_header;
+			unsigned char* packet;
+			int err = pcap_next_ex(pcap_interface, &pcap_header, (const u_char**)&packet);
+			switch (err)
+			{
+				case 1: break;    // ok
+				case 0: continue; // timeout expired, try again
+				default:
+					throw wibble::exception::Pcap(
+							pcap_geterr(pcap_interface),
+							"getting a new packet from the network");
+			}
 
 			NetBuffer pkt(packet, captureSize, false);
 
